==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hits-ak (irakurrienak)");
define("_BROWSERS","Nabigatzaileak");
define("_OPERATINGSYS","Sistema Eragileak");
define("_UNKNOWN","Ezezaguna");
define("_OTHER","Beste bat / Ezezaguna");
define("_MISCSTATS","Estatistika desberdinak");
define("_REGUSERS","Erregistratutako sistema-kideak:");
define("_ACTIVEAUTHORS","Autore aktiboenak:");
define("_STORIESPUBLISHED","Publikatutako notiziak:");
define("_SACTIVETOPICS","Aktibo dauden gaiak:");
define("_COMMENTSPOSTED","Bidalitako komentarioak:");
define("_SSPECIALSECT","Atal bereziak:");
define("_ARTICLESSEC","Ataletako artikuloak:");
define("_LINKSINLINKS","Loturak:");
define("_LINKSCAT","Loturetako atalak:");
define("_NEWSWAITING","Itxaroten dauden notiziak:");
define("_NUKEVERSION","PHP-Nuke bertsioa:");
define("_SEARCHENGINES","Bilatzaileak");
define("_BOTS","Robotak/Spider-ak");
define("_STATS","Bisita estatistikak");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hits-ak (irakurrienak)");
define("_BROWSERS","Nabigatzaileak");
define("_OPERATINGSYS","Sistema Eragileak");
define("_UNKNOWN","Ezezaguna");
define("_OTHER","Beste bat / Ezezaguna");
define("_MISCSTATS","Estatistika desberdinak");
define("_REGUSERS","Erregistratutako sistema-kideak:");
define("_ACTIVEAUTHORS","Autore aktiboenak:");
define("_STORIESPUBLISHED","Publikatutako notiziak:");
define("_SACTIVETOPICS","Aktibo dauden gaiak:");
define("_COMMENTSPOSTED","Bidalitako komentarioak:");
define("_SSPECIALSECT","Atal bereziak:");
define("_ARTICLESSEC","Ataletako artikuloak:");
define("_LINKSINLINKS","Loturak:");
define("_LINKSCAT","Loturetako atalak:");
define("_NEWSWAITING","Itxaroten dauden notiziak:");
define("_NUKEVERSION","PHP-Nuke bertsioa:");
define("_SEARCHENGINES","Bilatzaileak");
define("_BOTS","Robotak/Spider-ak");
define("_STATS","Bisita estatistikak");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
